@@ -52,8 +52,14 @@ class ImageOverlay(skrt.image.Image):
         no_ytick_labels=False,
         include_image=True, 
         opacity=None, 
+        intensity=None,
         mpl_kwargs=None,
         show=True,
+        mask=None,
+        mask_threshold=0.5,
+        masked=True,
+        invert_mask=False,
+        mask_color="black",
         **kwargs
     ):
         """Plot this overlay, optionally overlaid on its associated Image.
@@ -122,6 +128,27 @@ class ImageOverlay(skrt.image.Image):
         show : bool, default = True
             If True, the plot will be displayed immediately.
 
+        mask : Image/list/ROI/str/StructureSet, default=None
+            Image object representing a mask or a source from which
+            an Image object can be initialised.  In addition to the
+            sources accepted by the Image constructor, the source
+            may be an ROI, a list of ROIs or a StructureSet.  In the
+            latter cases, the mask image is derived from the ROI mask(s).
+
+        mask_threshold : float, default=0.5
+            Threshold for mask data.  Values above and below this value are
+            set to True and False respectively.  Taken into account only
+            if the mask image has non-boolean data.
+
+        masked : bool, default=True
+            If True and a mask is specified, the image is masked.
+
+        invert_mask : bool, default=False
+            If True and a mask is applied, the mask will be inverted.
+
+        mask_color : matplotlib color, default="black"
+            color in which to plot masked areas.
+
         `**`kwargs:
             Keyword args to pass to skrt.image.Image.plot().
         """
@@ -138,7 +165,10 @@ class ImageOverlay(skrt.image.Image):
                     show=False, title="", colorbar=max((colorbar - 1), 0),
                     no_xlabel=no_xlabel, no_ylabel=no_ylabel,
                     no_xtick_labels=no_xtick_labels,
-                    no_ytick_labels=no_ytick_labels)
+                    no_ytick_labels=no_ytick_labels,
+                    mask=mask, mask_threshold=mask_threshold,
+                    masked=masked, invert_mask=invert_mask,
+                    mask_color=mask_color)
 
             # Use default transprency if plotting image and opacity is None
             if opacity is None:
@@ -150,6 +180,13 @@ class ImageOverlay(skrt.image.Image):
         if opacity is not None:
             mpl_kwargs["alpha"] = opacity
 
+        # Add intensity to mpl_kwargs
+        if mpl_kwargs is None:
+            mpl_kwargs = {}
+        if intensity is not None:
+            mpl_kwargs["vmin"] = intensity[0]
+            mpl_kwargs["vmax"] = intensity[1]
+
         # Plot self
         skrt.image.Image.plot(
             self, 
@@ -166,6 +203,11 @@ class ImageOverlay(skrt.image.Image):
             no_ylabel=no_ylabel,
             no_xtick_labels=no_xtick_labels,
             no_ytick_labels=no_ytick_labels,
+            mask=mask,
+            mask_threshold=mask_threshold,
+            masked=masked,
+            invert_mask=invert_mask,
+            mask_color=mask_color,
             **kwargs
         )
 
@@ -276,8 +318,8 @@ class Dose(ImageOverlay):
             dose_max=max(doses)
         return dose_max
 
-    def plot_DVH(self, rois=[], bins=50, dose_min=0, dose_max=None,
-            figsize=(8, 4), lw=2, n_colour=10, cmap='turbo', grid=True,
+    def plot_dvh(self, rois=[], bins=50, dose_min=0, dose_max=None,
+            figsize=(8, 4), lw=2, n_colour=None, cmap='turbo', grid=True,
             fname=None, legend_bbox_to_anchor=(1.01, 0.5),
             legend_loc='center left'):
         '''
@@ -308,8 +350,10 @@ class Dose(ImageOverlay):
             Width (relative to matplotlib default) of line used in drawing
             histogram outlines.
 
-        n_colour : int, default=10
-            Number of colours over which to cycle when drawing histograms.
+        n_colour : int, default=None
+            Number of colours over which to cycle when drawing histograms
+            based on a colour map.  In None, the ROI color attribute
+            is used to define histogram colour.
 
         cmap : str, default='turbo'
             Name of a matplotlib colour map from which to define set of
@@ -326,11 +370,6 @@ class Dose(ImageOverlay):
             Name of file for saving output.
         '''
 
-        # Create figure and define the list of colours.
-        fig, ax = matplotlib.pyplot.subplots(figsize=figsize)
-        colours = matplotlib.cm.get_cmap(cmap)(np.linspace(0, 1,n_colour))
-        ax.set_prop_cycle(color=colours)
-
         # Ensure that rois is a list.
         if issubclass(type(rois),
                 (skrt.structures.ROI, skrt.structures.StructureSet)):
@@ -351,6 +390,14 @@ class Dose(ImageOverlay):
         if dose_max is None:
             dose_max = self.get_max_dose_in_rois(all_rois)
 
+        # Create figure and define the list of colours.
+        fig, ax = matplotlib.pyplot.subplots(figsize=figsize)
+        if n_colour is None:
+            colours = [roi.color for roi in all_rois]
+        else:
+            colours = matplotlib.cm.get_cmap(cmap)(np.linspace(0, 1, n_colour))
+        ax.set_prop_cycle(color=colours)
+
         # Plot the dose-volume histograms, and extract information for legend.
         lines= []
         labels= []
